// test_obj_sai_menu_oled_i2c.ino 
// Test des objets sai_oled et menu_oled
// Castoo https://castoo.fr
// Décembre 2019
// Màj février 2021

#include "SSD1306Wire.h"
#include "sai_oled_i2c.h"
#include "menu_oled_i2c.h"

// l'adresse I2C (ici 0x3C) peut être différente en fonction du module utilisé
//SSD1306Wire  display(0x3c, 4, 5); // I2C sur un esp8266 donc gpio 4 > SDA & gpio 5 > SCL
SSD1306Wire  display(0x3c, D2, D1); // I2C sur un Wemos D1 mini (esp8266 donc gpio 4 (ou D2) > SDA & gpio 5 (ou D1) > SCL)

#define adr_pcf85741 0x21 // Adresse du circuit I2C 8 I/O
#define encod_sw 0 // P0
#define encod_dt 1 // P1
#define encod_clk 2 // P2

// Pour initialiser les objets sai_oled et menu_oled il faut passer les sorties Gpio utilisées pour le bouton rotatif
// Il est également necessaire de preciser le nom de l'objet écran utilisé (celui-ci peut facilement être modifié)
// L'adresse du circuuit PCF8574 doit etre passé en premier parametre ceci permet l'utilisation de différents types de circuit I/O
// L'adresse peut etre 20 ou 21 ou tout autre suivant circuit ...
//sai_oled Sai_oled(adr, 16, 13, 0, display); // init saisie (Adresse PCF85741 0x21, Gpio vclk, Gpio vdt, Gpio vsw et nom de l'objet LCD)
sai_oled Sai_oled(adr_pcf85741, encod_clk, encod_dt, encod_sw, display); // init saisie (Adresse PCF85741 0x21, Gpio vclk, Gpio vdt, Gpio vsw et nom de l'objet LCD)
//menu_oled Menus_oled(adr, 16, 13, 0, display); // init saisie (Adresse PCF85741 0x21, Gpio vclk, Gpio vdt, Gpio vsw et nom de l'objet LCD)
menu_oled Menus_oled(adr_pcf85741, encod_clk, encod_dt, encod_sw, display); // init saisie (Adresse PCF85741 0x21, Gpio vclk, Gpio vdt, Gpio vsw et nom de l'objet LCD)
// Menus_oled.li_rot_sw()  Sortie SW du selecteur rotatif sera utilisée pour valider les delais d'attente

int A_menu; // Choix selectionné dans menu
const int nb_ch_menuA = 3; // choix du menu Principal
const String ch_menuA[] = {"Saisir votre nom", "Saisir votre prénom", "Afficher Nom Prénom"};
String _ch_menuA = * ch_menuA;
String nom = "";
String prenom = "";
String ch_result = "";

// Initialisation
void setup() { 
	// Init OLED
	display.init();
	display.flipScreenVertically();
	display.setFont(ArialMT_Plain_24);
	display.setTextAlignment(TEXT_ALIGN_CENTER);
	display.clear();
	// Init des objets sai_oled
	Sai_oled.init(); // Initialisation ecran pour saisie OLED
	Sai_oled.sortie_deb(false); // Invalide sortie balayage aprés chaque saisie (+ rapide mais perso, j'aime pas !) à tester à true...
} 

// Boucle principale
void loop(){
	A_menu = 0;
	A_menu = Menus_oled.init(nb_ch_menuA, _ch_menuA);
	delay(300);
	switch (A_menu){ // Menu général
		case 0 : // Saisie du nom
			Sai_oled.init(); // Initialisation ecran OLED pour saisie
			nom = Sai_oled.aff_menu_Alpha(); // On lance la saisie
			break;
		case 1 : // Saisie du prénom
			
			Sai_oled.init(); // Initialisation ecran OLED pour saisie
			prenom = Sai_oled.aff_menu_Alpha(); // On lance la saisie
			break;
		case 2 : // Affichage du nom et du prénom
			delay(200); // Anti rebond bouton
			ch_result = nom + " " + prenom;
			if(ch_result == " ") ch_result = "Vous devez faire une saisie !";
			display.setFont(ArialMT_Plain_10);
			display.setTextAlignment(TEXT_ALIGN_CENTER);
			display.clear();
			display.drawString(64, 25, ch_result);
			display.display();
			while(Menus_oled.li_rot_sw()){ // On attend que le bouton soit pressé pour sortir de l'affichage
				delay(10); 
			}
			break;
	}
	delay(800);
}
